@@ -66,8 +66,9 @@ def override(name, value):
 
 
 def load(dependencies, override=False, using: typing.Optional[provider.Provider] = None):
-    s = schema.Parser(override=override).load(dependencies)
-    s.resolve(schema.Resolver(using or provider))
+    provider = using or provider
+    s = schema.Parser(provider=provider, override=override).load(dependencies)
+    s.resolve(schema.Resolver(provider))
 
 
 def load_config(
